@@ -56,8 +56,7 @@ sub db_handle {
     my $p = shift;
     my $dsn    = oracle_test_dsn();
     my $dbuser = $ENV{ORACLE_USERID} || 'scott/tiger';
-    my $dbpass = $ENV{ORACLE_PASSWD} || '';
-    my $dbh    = DBI->connect_cached( $dsn, $dbuser, $dbpass, $p );
+    my $dbh    = DBI->connect_cached( $dsn, $dbuser, '', $p );
     return $dbh
 
 }
